==> pythonic_fp-3.3.2.tar.gz: pythonic_fp-3.3.2/src/pythonic_fp/homepage/compatible_versions.py <==
"""
Known Boring Math compatible versions.

Coordinated releases
====================

2025-12-02 - 3.3.2
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      2.0.0
Circular Array pythonic-fp-circulararray 6.0.0
Containers     pythonic-fp-containers    4.0.0
FP Tools       pythonic-fp-fptools       5.1.2
Gadgets        pythonic-fp-gadgets       4.0.1
Iterables      pythonic-fp-iterables     5.1.2
Numpy          pythonic-fp-numpy         0.1.1
Queues         pythonic-fp-queues        5.1.0
Splitends      pythonic-fp-splitends     2.0.0
============== ========================= =======

----

2025-09-28 - 3.2.0
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      2.0.0
Circular Array pythonic-fp-circulararray 6.0.0
Containers     pythonic-fp-containers    4.0.0
FP Tools       pythonic-fp-fptools       5.1.2
Gadgets        pythonic-fp-gadgets       3.1.0
Iterables      pythonic-fp-iterables     5.1.2
Queues         pythonic-fp-queues        5.1.0
Splitends      pythonic-fp-splitends     2.0.0
============== ========================= =======

----

2025-09-26 - 3.0.0
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      1.1.2
Circular Array pythonic-fp-circulararray 5.3.2
Containers     pythonic-fp-containers    3.0.1
FP Tools       pythonic-fp-fptools       5.1.1
Gadgets        pythonic-fp-gadgets       3.0.1
Iterables      pythonic-fp-iterables     5.1.1
Sentinels      pythonic-fp-sentinels     2.1.0
Splitends      pythonic-fp-splitends     1.0.2
============== ========================= =======

----

2025-08-02 - 1.1.0
------------------

========== ====================== =======
Name       PyPI Project           Version
========== ====================== =======
Containers pythonic-fp-containers 3.0.0
FP Tools   pythonic-fp-fptools    5.0.0
Iterables  pythonic-fp-iterables  5.0.0
Singletons pythonic-fp-singletons 1.0.0
Splitends  pythonic-fp-splitends  1.0.0
========== ====================== =======

"""

==> pythonic_fp-3.4.0.tar.gz: pythonic_fp-3.4.0/src/pythonic_fp/homepage/compatible_versions.py <==
"""
Known Boring Math compatible versions.

Coordinated releases
====================

2026-01-22 - 3.4.0
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      3.0.0
Circular Array pythonic-fp-circulararray 6.0.1
Containers     pythonic-fp-containers    4.0.1
FP Tools       pythonic-fp-fptools       5.2.0
Gadgets        pythonic-fp-gadgets       4.0.2
Iterables      pythonic-fp-iterables     5.1.3
Numpy          pythonic-fp-numpy         0.1.2
Queues         pythonic-fp-queues        5.1.1
Splitends      pythonic-fp-splitends     2.0.2
============== ========================= =======

----

2025-12-02 - 3.3.3
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      2.1.0
Circular Array pythonic-fp-circulararray 6.0.0
Containers     pythonic-fp-containers    4.0.0
FP Tools       pythonic-fp-fptools       5.1.2
Gadgets        pythonic-fp-gadgets       4.0.1
Iterables      pythonic-fp-iterables     5.1.2
Numpy          pythonic-fp-numpy         0.1.1
Queues         pythonic-fp-queues        5.1.0
Splitends      pythonic-fp-splitends     2.0.0
============== ========================= =======

----

2025-09-28 - 3.2.0
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      2.0.0
Circular Array pythonic-fp-circulararray 6.0.0
Containers     pythonic-fp-containers    4.0.0
FP Tools       pythonic-fp-fptools       5.1.2
Gadgets        pythonic-fp-gadgets       3.1.0
Iterables      pythonic-fp-iterables     5.1.2
Queues         pythonic-fp-queues        5.1.0
Splitends      pythonic-fp-splitends     2.0.0
============== ========================= =======

----

2025-09-26 - 3.0.0
------------------

============== ========================= =======
Name           PyPI Project              Version
============== ========================= =======
Booleans       pythonic-fp-booleans      1.1.2
Circular Array pythonic-fp-circulararray 5.3.2
Containers     pythonic-fp-containers    3.0.1
FP Tools       pythonic-fp-fptools       5.1.1
Gadgets        pythonic-fp-gadgets       3.0.1
Iterables      pythonic-fp-iterables     5.1.1
Sentinels      pythonic-fp-sentinels     2.1.0
Splitends      pythonic-fp-splitends     1.0.2
============== ========================= =======

----

2025-08-02 - 1.1.0
------------------

========== ====================== =======
Name       PyPI Project           Version
========== ====================== =======
Containers pythonic-fp-containers 3.0.0
FP Tools   pythonic-fp-fptools    5.0.0
Iterables  pythonic-fp-iterables  5.0.0
Singletons pythonic-fp-singletons 1.0.0
Splitends  pythonic-fp-splitends  1.0.0
========== ====================== =======

"""
